#[repr(i32)]pub enum MemberType {
Node = 0,
Way = 1,
Relation = 2,
}Variants
Implementations
Sourceimpl MemberType
impl MemberType
Sourceimpl MemberType
impl MemberType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.