pub struct DenseNodes {
pub id: Vec<i64>,
pub denseinfo: Option<DenseInfo>,
pub lat: Vec<i64>,
pub lon: Vec<i64>,
pub keys_vals: Vec<i32>,
}Fields
id: Vec<i64>DELTA coded
denseinfo: Option<DenseInfo>lat: Vec<i64>DELTA coded
lon: Vec<i64>DELTA coded
keys_vals: Vec<i32>Special packing of keys and vals into one array. May be empty if all nodes in this block are tagless.