pub struct DenseInfo {
pub version: Vec<i32>,
pub timestamp: Vec<i64>,
pub changeset: Vec<i64>,
pub uid: Vec<i32>,
pub user_sid: Vec<i32>,
pub visible: Vec<bool>,
}Expand description
- Optional metadata that may be included into each primitive. Special dense format used in DenseNodes.
Fields
version: Vec<i32>timestamp: Vec<i64>DELTA coded
changeset: Vec<i64>DELTA coded
uid: Vec<i32>DELTA coded
user_sid: Vec<i32>String IDs for usernames. DELTA coded
visible: Vec<bool>The visible flag is used to store history information. It indicates that the current object version has been created by a delete operation on the OSM API. When a writer sets this flag, it MUST add a required_features tag with value “HistoricalInformation” to the HeaderBlock. If this flag is not available for some object it MUST be assumed to be true if the file has the required_features tag “HistoricalInformation” set.